@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::MetroAreaDemographicReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -26,6 +26,7 @@ our @_attributes = (qw/
     AdDistribution
     Country
     LanguageAndRegion
+    LanguageCode
 /);
 
 sub _attributes {
@@ -37,6 +38,7 @@ our %_attribute_type = (
     AdDistribution => 'AdDistributionReportFilter',
     Country => 'CountryReportFilter',
     LanguageAndRegion => 'LanguageAndRegionReportFilter',
+    LanguageCode => 'ArrayOfstring',
 );
 
 sub _attribute_type {
@@ -51,6 +53,7 @@ our %_attribute_min_occurs = (
     AdDistribution => 0,
     Country => 0,
     LanguageAndRegion => 0,
+    LanguageCode => 0,
 );
 
 sub _attribute_min_occurs {
@@ -89,5 +92,9 @@ Gets/sets Country (CountryReportFilter)
 
 Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
 
+=head2 LanguageCode
+
+Gets/sets LanguageCode (ArrayOfstring)
+
 =cut
 
