@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V8::ReportingService::DeviceTypeReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,6 +19,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     Computer
     NonSmartPhone
     SmartPhone
+    Tablet
 
 =cut
 
@@ -34,4 +35,8 @@ sub SmartPhone {
     return 'SmartPhone';
 }
 
+sub Tablet {
+    return 'Tablet';
+}
+
 1;
